package sun.awt.image;

import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.security.Permission;
import java.io.IOException;
import java.net.SocketPermission;
import java.io.FilePermission;
import sun.net.util.URLUtil;
import java.net.URLConnection;
import java.net.URL;

public class URLImageSource extends InputStreamImageSource
{
    URL url;
    URLConnection conn;
    String actualHost;
    int actualPort;
    
    public URLImageSource(URL url) {
        SecurityManager securityManager = System.getSecurityManager();
        if (securityManager != null) {
            try {
                Permission connectPermission = URLUtil.getConnectPermission(url);
                if (connectPermission != null) {
                    try {
                        securityManager.checkPermission(connectPermission);
                    }
                    catch (SecurityException ex) {
                        if (connectPermission instanceof FilePermission && connectPermission.getActions().indexOf("read") != -1) {
                            securityManager.checkRead(connectPermission.getName());
                        }
                        else if (connectPermission instanceof SocketPermission && connectPermission.getActions().indexOf("connect") != -1) {
                            securityManager.checkConnect(url.getHost(), url.getPort());
                        }
                        else {
                            throw ex;
                        }
                    }
                }
            }
            catch (IOException ex2) {
                securityManager.checkConnect(url.getHost(), url.getPort());
            }
        }
        this.url = url;
    }
    
    public URLImageSource(String spec) throws MalformedURLException {
        this(new URL(null, spec));
    }
    
    public URLImageSource(URL url, URLConnection conn) {
        this(url);
        this.conn = conn;
    }
    
    public URLImageSource(URLConnection urlConnection) {
        this(urlConnection.getURL(), urlConnection);
    }
    
    @Override
    final boolean checkSecurity(Object context, boolean b) {
        if (this.actualHost != null) {
            try {
                SecurityManager securityManager = System.getSecurityManager();
                if (securityManager != null) {
                    securityManager.checkConnect(this.actualHost, this.actualPort, context);
                }
            }
            catch (SecurityException ex) {
                if (!b) {
                    throw ex;
                }
                return false;
            }
        }
        return true;
    }
    
    private synchronized URLConnection getConnection() throws IOException {
        if (this.conn != null) {
            URLConnection urlConnection = this.conn;
            this.conn = null;
            return urlConnection;
        }
        return this.url.openConnection();
    }
    
    @Override
    protected ImageDecoder getDecoder() {
        InputStream inputStream = null;
        URLConnection connection = null;
        String contentType;
        try {
            connection = this.getConnection();
            inputStream = connection.getInputStream();
            contentType = connection.getContentType();
            URL url = connection.getURL();
            if (url != this.url && (!url.getHost().equals(this.url.getHost()) || url.getPort() != this.url.getPort())) {
                if (this.actualHost != null && (!this.actualHost.equals(url.getHost()) || this.actualPort != url.getPort())) {
                    throw new SecurityException("image moved!");
                }
                this.actualHost = url.getHost();
                this.actualPort = url.getPort();
            }
        }
        catch (IOException ex) {
            if (inputStream != null) {
                try {
                    inputStream.close();
                }
                catch (IOException ex2) {}
            }
            else if ((connection instanceof HttpURLConnection)) {
                ((HttpURLConnection)connection).disconnect();
            }
            return null;
        }
        ImageDecoder imageDecoder = this.decoderForType(inputStream, contentType);
        if (imageDecoder == null) {
            imageDecoder = super.getDecoder(inputStream);
        }
        if (imageDecoder == null) {
            if (inputStream != null) {
                try {
                    inputStream.close();
                }
                catch (IOException ex3) {}
            }
            else if ((connection instanceof HttpURLConnection)) {
                ((HttpURLConnection)connection).disconnect();
            }
        }
        return imageDecoder;
    }
}
